==> aws-java-sdk-ecs-1.10.11-sources.jar: com/amazonaws/services/ecs/model/transform/VolumeFromJsonUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.ecs.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.ecs.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * Volume From JSON Unmarshaller
 */
public class VolumeFromJsonUnmarshaller implements Unmarshaller<VolumeFrom, JsonUnmarshallerContext> {

    public VolumeFrom unmarshall(JsonUnmarshallerContext context) throws Exception {
        VolumeFrom volumeFrom = new VolumeFrom();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null) token = context.nextToken();
        if (token == VALUE_NULL) return null;

        while (true) {
            if (token == null) break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("sourceContainer", targetDepth)) {
                    context.nextToken();
                    volumeFrom.setSourceContainer(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("readOnly", targetDepth)) {
                    context.nextToken();
                    volumeFrom.setReadOnly(BooleanJsonUnmarshaller.getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null || context.getLastParsedParentElement().equals(currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth) break;
                }
            }

            token = context.nextToken();
        }
        
        return volumeFrom;
    }

    private static VolumeFromJsonUnmarshaller instance;
    public static VolumeFromJsonUnmarshaller getInstance() {
        if (instance == null) instance = new VolumeFromJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-ecs-1.10.41-sources.jar: com/amazonaws/services/ecs/model/transform/VolumeFromJsonUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.ecs.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.ecs.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * VolumeFrom JSON Unmarshaller
 */
public class VolumeFromJsonUnmarshaller implements
        Unmarshaller<VolumeFrom, JsonUnmarshallerContext> {

    public VolumeFrom unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        VolumeFrom volumeFrom = new VolumeFrom();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("sourceContainer", targetDepth)) {
                    context.nextToken();
                    volumeFrom.setSourceContainer(StringJsonUnmarshaller
                            .getInstance().unmarshall(context));
                }
                if (context.testExpression("readOnly", targetDepth)) {
                    context.nextToken();
                    volumeFrom.setReadOnly(BooleanJsonUnmarshaller
                            .getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return volumeFrom;
    }

    private static VolumeFromJsonUnmarshaller instance;

    public static VolumeFromJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new VolumeFromJsonUnmarshaller();
        return instance;
    }
}
